@@ -4,6 +4,7 @@ import sys, os, re, subprocess
 
 from django.conf import settings
 from django.core.management.base import CommandError
+from django.core.management.utils import get_random_secret_key
 
 from simple_deploy.management.commands.utils import deploy_messages as d_msgs
 from simple_deploy.management.commands.utils import deploy_messages_heroku as dh_msgs
@@ -33,6 +34,8 @@ class HerokuDeployer:
         self._check_allowed_hosts()
         self._configure_db()
         self._configure_static_files()
+        self._configure_debug()
+        self._configure_secret_key()
         self._conclude_automate_all()
         self._show_success_message()
 
@@ -279,6 +282,46 @@ class HerokuDeployer:
         self.stdout.write("    Added placeholder file to static files directory.")
 
 
+    def _configure_debug(self):
+        """Use an env var to manage DEBUG setting, and set to False."""
+
+        # Config variables are strings, which always causes confusion for people
+        #   when setting boolean env vars. A good habit is to use something other than
+        #   True or False, so it's clear we're not trying to use Python's default
+        #   boolean values.
+        # Here we use 'TRUE' and 'FALSE'. Then a simple test:
+        #    os.environ.get('DEBUG') == 'TRUE'
+        # returns the bool value True for 'TRUE', and False for 'FALSE'.
+        # Taken from: https://stackoverflow.com/a/56828137/748891
+
+        self.stdout.write("  Setting DEBUG env var...")
+        subprocess.run(["heroku", "config:set", f"DEBUG=FALSE"])
+        self.stdout.write("    Set DEBUG config variable to FALSE.")
+
+        # Modify settings to use the DEBUG config variable.
+        new_setting = "DEBUG = os.getenv('DEBUG') == 'TRUE'"
+        msg_added = "    Added DEBUG setting for Heroku."
+        msg_already_set = "    Found DEBUG setting for Heroku."
+        self._add_heroku_setting(new_setting, msg_added, msg_already_set)
+
+
+    def _configure_secret_key(self):
+        """Use an env var to manage the secret key."""
+        # Generate a new key.
+        new_secret_key = get_random_secret_key()
+
+        # Set the new key as an env var on Heroku.
+        self.stdout.write("  Setting new secret key for Heroku...")
+        subprocess.run(["heroku", "config:set", f"SECRET_KEY={new_secret_key}"])
+        self.stdout.write("    Set SECRET_KEY config variable.")
+
+        # Modify settings to use the env var's value as the secret key.
+        new_setting = "SECRET_KEY = os.getenv('SECRET_KEY')"
+        msg_added = "    Added SECRET_KEY setting for Heroku."
+        msg_already_set = "    Found SECRET_KEY setting for Heroku."
+        self._add_heroku_setting(new_setting, msg_added, msg_already_set)
+
+
     def _conclude_automate_all(self):
         """Finish automating the push to Heroku."""
         if not self.sd.automate_all:
